@@ -50,7 +50,7 @@ def format_datetime(dt):
             dtformat = datetime.datetime.strptime(dt, '%Y-%m-%d')
             ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
         elif '+0800' in dt:
-            dtformat = datetime.strptime(dt, '%a %b %d %H:%M:%S +0800 %Y')
+            dtformat = datetime.datetime.strptime(dt, '%a %b %d %H:%M:%S +0800 %Y')
             ret = datetime.datetime.strftime(dtformat, '%Y-%m-%d %H:%M:%S')
         else:
             ret = dt
